@@ -1,8 +1,15 @@
-# mypy: ignore-errors
+from unittest.mock import patch
 
 import pytest
-from unittest.mock import patch
-from litecli.packages.special.llm import handle_llm, FinishIteration, USAGE
+
+import litecli.packages.special.llm as llm_module
+from litecli.packages.special.llm import USAGE, FinishIteration, handle_llm
+
+
+@pytest.fixture(autouse=True)
+def enable_llm(monkeypatch):
+    monkeypatch.setattr(llm_module, "LLM_IMPORTED", True)
+    monkeypatch.setattr(llm_module, "LLM_CLI_COMMANDS", ["models"])
 
 
 @patch("litecli.packages.special.llm.llm")
